﻿using System.Windows.Input;
using JulMar.Windows.Mvvm;

namespace MessageMediatorExamples.ViewModels
{
    public class MainViewModel : ViewModel
    {
        private string _text, _font, _foregroundColor, _backgroundColor;
        private double _fontSize;

        public ICommand ChangeColors { get; private set; }
        public ICommand ChangeFonts { get; private set; }

        public string Text
        {
            get { return _text; }
            set { _text = value; OnPropertyChanged(() => Text); }
        }

        public string Font
        {
            get { return _font; }
            set { _font = value; OnPropertyChanged(() => Font); }
        }

        public string ForegroundColor
        {
            get { return _foregroundColor; }
            set { _foregroundColor = value; OnPropertyChanged(() => ForegroundColor); }
        }

        public string BackgroundColor
        {
            get { return _backgroundColor; }
            set { _backgroundColor = value; OnPropertyChanged(() => BackgroundColor); }
        }

        public double FontSize
        {
            get { return _fontSize; }
            set { _fontSize = value; OnPropertyChanged("FontSize"); }
        }

        public MainViewModel()
        {
            Text = "Four score and seven years ago our fathers brought forth, upon this continent, a new nation, conceived in Liberty, and dedicated to the proposition that all men are created equal. Now we are engaged in a great civil war, testing whether that nation, or any nation so conceived, and so dedicated, can long endure. We are met here on a great battlefield of that war. We have come to dedicate a portion of it as a final resting place for those who here gave their lives that that nation might live. It is altogether fitting and proper that we should do this. But in a larger sense we can not dedicate - we can not consecrate - we can not hallow this ground. The brave men, living and dead, who struggled, here, have consecrated it far above our poor power to add or detract. The world will little note, nor long remember, what we say here, but can never forget what they did here. It is for us, the living, rather to be dedicated here to the unfinished work which they have, thus far, so nobly carried on. It is rather for us to be here dedicated to the great task remaining before us - that from these honored dead we take increased devotion to that cause for which they here gave the last full measure of devotion - that we here highly resolve that these dead shall not have died in vain; that this nation shall have a new birth of freedom; and that this government of the people, by the people, for the people, shall not perish from the earth.";
            Font = "Arial";
            ForegroundColor = "Black";
            BackgroundColor = "White";

            ChangeColors = new DelegatingCommand(OnChangeColors);
            ChangeFonts = new DelegatingCommand(OnChangeFonts);
        }

        private void OnChangeColors()
        {
            // Use built-in SendMessage (inherited from ViewModel)
            this.SendMessage(ViewMessages.ChangeColors, this);
        }

        private void OnChangeFonts()
        {
            this.SendMessage(ViewMessages.ChangeFonts, this);
        }
    }
}
